From 742060f78645082d48cf8a8fd885b666629458e9 Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <dgustafsson@postgresql.org>
Date: Mon, 27 Feb 2023 14:12:53 +0100
Subject: [PATCH v3] Fix outdated references to guc.c

Commit 0a20ff54f split out the GUC variables from guc.c into a new file
guc_tables.c. This updates comments referencing guc.c regarding variables
which are now in guc_tables.c.

Reviewed-by: Tom Lane <tgl@sss.pgh.pa.us>
Discussion: https://postgr.es/m/6B50C70C-8C1F-4F9A-A7C0-EEAFCC032406@yesql.se
---
 src/backend/commands/variable.c               | 2 +-
 src/backend/libpq/be-secure-openssl.c         | 3 ++-
 src/backend/storage/lmgr/predicate.c          | 6 +++---
 src/bin/pg_dump/dumputils.c                   | 2 +-
 src/include/miscadmin.h                       | 2 +-
 src/test/modules/test_misc/t/003_check_guc.pl | 8 ++++----
 src/timezone/pgtz.c                           | 2 +-
 7 files changed, 13 insertions(+), 12 deletions(-)

diff --git a/src/backend/commands/variable.c b/src/backend/commands/variable.c
index bb0f5de4c2..f0f2e07655 100644
--- a/src/backend/commands/variable.c
+++ b/src/backend/commands/variable.c
@@ -877,7 +877,7 @@ assign_session_authorization(const char *newval, void *extra)
  * a translation of "none" to InvalidOid.  Otherwise this is much like
  * SET SESSION AUTHORIZATION.
  */
-extern char *role_string;		/* in guc.c */
+extern char *role_string;		/* in guc_tables.c */
 
 bool
 check_role(char **newval, void **extra, GucSource source)
diff --git a/src/backend/libpq/be-secure-openssl.c b/src/backend/libpq/be-secure-openssl.c
index b3747f4fd8..2cd2d7fe1b 100644
--- a/src/backend/libpq/be-secure-openssl.c
+++ b/src/backend/libpq/be-secure-openssl.c
@@ -1557,7 +1557,8 @@ X509_NAME_to_cstring(X509_NAME *name)
  * Convert TLS protocol version GUC enum to OpenSSL values
  *
  * This is a straightforward one-to-one mapping, but doing it this way makes
- * guc.c independent of OpenSSL availability and version.
+ * the definition of ssl_min_protocol_version and ssl_max_protocol_version
+ * independent of OpenSSL availability and version.
  *
  * If a version is passed that is not supported by the current OpenSSL
  * version, then we return -1.  If a nonnegative value is returned,
diff --git a/src/backend/storage/lmgr/predicate.c b/src/backend/storage/lmgr/predicate.c
index bfc352aed8..0f7f7ba5f1 100644
--- a/src/backend/storage/lmgr/predicate.c
+++ b/src/backend/storage/lmgr/predicate.c
@@ -364,9 +364,9 @@ static SERIALIZABLEXACT *OldCommittedSxact;
  * attempt to degrade performance (mostly as false positive serialization
  * failure) gracefully in the face of memory pressure.
  */
-int			max_predicate_locks_per_xact;	/* set by guc.c */
-int			max_predicate_locks_per_relation;	/* set by guc.c */
-int			max_predicate_locks_per_page;	/* set by guc.c */
+int			max_predicate_locks_per_xact;	/* in guc_tables.c */
+int			max_predicate_locks_per_relation;	/* in guc_tables.c */
+int			max_predicate_locks_per_page;	/* in guc_tables.c */
 
 /*
  * This provides a list of objects in order to track transactions
diff --git a/src/bin/pg_dump/dumputils.c b/src/bin/pg_dump/dumputils.c
index 9753a6d868..079693585c 100644
--- a/src/bin/pg_dump/dumputils.c
+++ b/src/bin/pg_dump/dumputils.c
@@ -683,7 +683,7 @@ emitShSecLabels(PGconn *conn, PGresult *res, PQExpBuffer buffer,
  * currently known to guc.c, so that it'd be unsafe for extensions to declare
  * GUC_LIST_QUOTE variables anyway.  Lacking a solution for that, it doesn't
  * seem worth the work to do more than have this list, which must be kept in
- * sync with the variables actually marked GUC_LIST_QUOTE in guc.c.
+ * sync with the variables actually marked GUC_LIST_QUOTE in guc_tables.c.
  */
 bool
 variable_is_guc_list_quote(const char *name)
diff --git a/src/include/miscadmin.h b/src/include/miscadmin.h
index c309e0233d..06a86f9ac1 100644
--- a/src/include/miscadmin.h
+++ b/src/include/miscadmin.h
@@ -291,7 +291,7 @@ extern void PreventCommandIfReadOnly(const char *cmdname);
 extern void PreventCommandIfParallelMode(const char *cmdname);
 extern void PreventCommandDuringRecovery(const char *cmdname);
 
-/* in utils/misc/guc.c */
+/* in utils/misc/guc_tables.c */
 extern PGDLLIMPORT int trace_recovery_messages;
 extern int	trace_recovery(int trace_level);
 
diff --git a/src/test/modules/test_misc/t/003_check_guc.pl b/src/test/modules/test_misc/t/003_check_guc.pl
index 1786cd1929..e9f33f3c77 100644
--- a/src/test/modules/test_misc/t/003_check_guc.pl
+++ b/src/test/modules/test_misc/t/003_check_guc.pl
@@ -13,7 +13,7 @@ $node->start;
 
 # Grab the names of all the parameters that can be listed in the
 # configuration sample file.  config_file is an exception, it is not
-# in postgresql.conf.sample but is part of the lists from guc.c.
+# in postgresql.conf.sample but is part of the lists from guc_tables.c.
 my $all_params = $node->safe_psql(
 	'postgres',
 	"SELECT name
@@ -82,7 +82,7 @@ is(scalar(@missing_from_file),
 	0, "no parameters missing from postgresql.conf.sample");
 
 my @missing_from_list = grep(!$all_params_hash{$_}, @gucs_in_file);
-is(scalar(@missing_from_list), 0, "no parameters missing from guc.c");
+is(scalar(@missing_from_list), 0, "no parameters missing from guc_tables.c");
 
 my @sample_intersect = grep($not_in_sample_hash{$_}, @gucs_in_file);
 is(scalar(@sample_intersect),
@@ -91,12 +91,12 @@ is(scalar(@sample_intersect),
 # These would log some information only on errors.
 foreach my $param (@missing_from_file)
 {
-	print("found GUC $param in guc.c, missing from postgresql.conf.sample\n");
+	print("found GUC $param in guc_tables.c, missing from postgresql.conf.sample\n");
 }
 foreach my $param (@missing_from_list)
 {
 	print(
-		"found GUC $param in postgresql.conf.sample, with incorrect info in guc.c\n"
+		"found GUC $param in postgresql.conf.sample, with incorrect info in guc_tables.c\n"
 	);
 }
 foreach my $param (@sample_intersect)
diff --git a/src/timezone/pgtz.c b/src/timezone/pgtz.c
index 89b69fd2af..c03078f7c8 100644
--- a/src/timezone/pgtz.c
+++ b/src/timezone/pgtz.c
@@ -364,7 +364,7 @@ pg_timezone_initialize(void)
 	 * We may not yet know where PGSHAREDIR is (in particular this is true in
 	 * an EXEC_BACKEND subprocess).  So use "GMT", which pg_tzset forces to be
 	 * interpreted without reference to the filesystem.  This corresponds to
-	 * the bootstrap default for these variables in guc.c, although in
+	 * the bootstrap default for these variables in guc_tables.c, although in
 	 * principle it could be different.
 	 */
 	session_timezone = pg_tzset("GMT");
-- 
2.32.1 (Apple Git-133)

